@@ -156,7 +156,7 @@ class GenerateCitationNet():
                 if key in data.keys():
                     tmpDict[key] = data[key][0]
                 else:
-                    tmpDict[key]
+                    tmpDict[key] = ''
             self.mainNode = (
                 doi,
                 tmpDict['title'],
